@@ -2,8 +2,7 @@ import uuid
 from typing import Callable
 
 import structlog
-from django.core.exceptions import PermissionDenied
-from django.http import Http404, HttpRequest, HttpResponse
+from django.http import HttpRequest, HttpResponse
 
 from payla_utils.settings import payla_utils_settings
 
@@ -45,35 +44,13 @@ class RequestMiddleware:
         ip, _ = get_client_ip(request)
         structlog.contextvars.bind_contextvars(ip=ip)
 
-        self._raised_exception = False
-
         response = self.get_response(request)
-        if not self._raised_exception:
-            self.bind_user_id(request)
+
+        self.bind_user_id(request)
 
         structlog.contextvars.clear_contextvars()
         return response
 
-    @staticmethod
-    def format_request(request: HttpRequest) -> str:
-        return f"{request.method} {request.get_full_path()}"
-
-    def process_exception(self, request: HttpRequest, exception: Exception) -> None:
-        if isinstance(exception, (Http404, PermissionDenied)):
-            # We don't log an exception here, and we don't set that we handled
-            # an error as we want the standard `request_finished` log message
-            # to be emitted.
-            return
-
-        self._raised_exception = True
-
-        self.bind_user_id(request)
-        logger.exception(
-            "request_failed",
-            code=500,
-            request=self.format_request(request),
-        )
-
     @staticmethod
     def bind_user_id(request: HttpRequest) -> None:
         if hasattr(request, "user") and request.user is not None:
